@@ -116,7 +116,7 @@ class APIObject:
         """
         :return: Returns a JSON presentation of the APIObject.
         """
-        return json.dumps(self.model._primitive(), indent=indent, encoding='utf-8').strip().decode('utf-8')
+        return json.dumps(self.model._primitive(), indent=indent).strip()
 
     def kind(self, lowercase=True, if_missing=_DEFAULT):
         """
@@ -716,7 +716,7 @@ class APIObject:
         r = Result("process")
         r.add_action(oc_action(self.context, "process", cmd_args=["-f", "-", base_args, cmd_args], stdin_obj=template))
         r.fail_if("Error processing template")
-        return APIObject(r.out()).elements()
+        return APIObject(string_to_model=r.out()).elements()
 
     def do_i_own(self, apiobj):
 
